@@ -69,6 +69,9 @@
 *************************************************************************
 */
 
+#define WAN_TE_CHIP_PMC		0x00
+#define WAN_TE_CHIP_DM		0x01
+
 #define NUM_OF_T1_CHANNELS	24
 #define NUM_OF_E1_TIMESLOTS	31
 #define NUM_OF_E1_CHANNELS	32
@@ -194,16 +197,16 @@
 		((mode) == WAN_TE1_LIU_RLB_MODE) ? "Remote LIU Loopback" :	\
 		((mode) == WAN_TE1_LIU_DLB_MODE) ? "Dual LIU Loopback" :		\
 		((mode) == WAN_TE1_FR_FLB_MODE) ? "Framer Loopback" :		\
-		((mode) == WAN_TE1_FR_RLB_MODE) ? "Remote Framer Loopback" :	\
-		((mode) == WAN_TE1_FR_PLB_MODE) ? "Payload Framer Loopback" :	\
+		((mode) == WAN_TE1_FR_RLB_MODE) ? "Remote Loopback" :	\
+		((mode) == WAN_TE1_FR_PLB_MODE) ? "Payload Loopback" :	\
 						"Unknown Loopback"
 
 /* Line loopback activate/deactive modes */
-#define WAN_TE1_ACTIVATE_LB	0x01
-#define WAN_TE1_DEACTIVATE_LB	0x02
-#define WAN_TE1_LB_ACTION_DECODE(action)				\
-		((action) == WAN_TE1_ACTIVATE_LB) ? "Activate" :	\
-		((action) == WAN_TE1_DEACTIVATE_LB) ? "Deactivate" :\
+#define WAN_TE1_LB_ENABLE	0x01
+#define WAN_TE1_LB_DISABLE	0x02
+#define WAN_TE1_LB_ACTION_DECODE(action)			\
+		((action) == WAN_TE1_LB_ENABLE) ? "Enable" :	\
+		((action) == WAN_TE1_LB_DISABLE) ? "Disable" :	\
 						"Unknown"
 
 /* T1/E1 front end Master clock source */
