@@ -150,7 +150,8 @@ static int sdla_56k_get_fe_status(sdla_fe_t *fe, unsigned char *status, int notu
 u_int32_t sdla_56k_alarm(sdla_fe_t *fe, int manual_read)
 {
 
-	unsigned short status = 0x00;
+	unsigned short 	status = 0x00;
+	sdla_t		*card = (sdla_t *)fe->card;
 	
 	AFT_FUNC_DEBUG();
 
@@ -213,6 +214,10 @@ u_int32_t sdla_56k_alarm(sdla_fe_t *fe, int manual_read)
 				}
 				DEBUG_EVENT("%s: 56k Connected\n",
 							fe->name);
+
+				if (card->wandev.te_link_state){
+					card->wandev.te_link_state(card);
+				}	
 			}
 		}else{
 			if((fe->fe_status == FE_CONNECTED) || 
@@ -228,6 +233,10 @@ u_int32_t sdla_56k_alarm(sdla_fe_t *fe, int manual_read)
 				}
 				DEBUG_EVENT("%s: 56k Disconnected (loopback)\n",
 						fe->name);
+	
+				if (card->wandev.te_link_state){
+					card->wandev.te_link_state(card);
+				}
 			}
 		}
 	}
