@@ -99,7 +99,9 @@ typedef struct {
 	int	wasringing;
 	
 	int				echotune;	/* echo tune */
-	struct wan_rm_echo_coefs	echoregs;	/* echo tune */
+	struct 	wan_rm_echo_coefs	echoregs;	/* echo tune */
+	int 	readcid;
+	unsigned int cidtimer;
 } tdmv_fxo_t;
 
 typedef struct {
@@ -707,6 +709,8 @@ static void wp_tdmv_remora_voicedaa_check_hook(wp_tdmv_remora_t *wr, int mod_no)
 			if (wr->mod[mod_no].fxo.ringdebounce <= 0) {
 				if (wr->mod[mod_no].fxo.wasringing) {
 					wr->mod[mod_no].fxo.wasringing = 0;
+					wr->mod[mod_no].fxo.readcid = 0;
+ 					wr->mod[mod_no].fxo.cidtimer = wr->intcount;
 					zt_hooksig(&wr->chans[mod_no], ZT_RXSIG_OFFHOOK);
 					DEBUG_TDMV("%s: Module %d: NO RING on span %d!\n",
 							wr->devname,
@@ -1487,6 +1491,39 @@ static int wp_tdmv_remora_is_rbsbits(wan_tdmv_t *wan_tdmv)
 	return 0;
 }
 
+
+#ifdef WAN_FAKE_POLARITY
+#warning "WAN_FAKE_POLARITY Enabled - Experimental"
+static inline void wp_tdmv_dtmfcheck_fakepolarity(wp_tdmv_remora_t *wr, int channo, unsigned char *rxbuf)
+{
+	sdla_t		*card = wr->card;
+	sdla_fe_t	*fe = &card->fe;
+	int sample;
+	int dtmf=1;
+
+    	/* only look for sound on the line if dtmf flag is on, it is an fxo card and line is onhook */ 
+	if (!dtmf || !(fe->rm_param.mod[channo].type == MOD_TYPE_FXO) || wr->mod[channo].fxo.offhook) {
+        	return;
+	}
+
+   	/* don't look for noise if we're already processing it, or there is a ringing tone */
+	if(!wr->mod[channo].fxo.readcid && !wr->mod[channo].fxo.wasringing  &&
+		wr->intcount > wr->mod[channo].fxo.cidtimer + 400 ) {
+		sample = ZT_XLAW((*rxbuf), (&(wr->chans[channo])));
+		if (sample > 16000 || sample < -16000) {
+			wr->mod[channo].fxo.readcid = 1;
+			wr->mod[channo].fxo.cidtimer = wr->intcount;
+			DEBUG_EVENT("DTMF CLIP on %i\n",channo+1);
+			zt_qevent_lock(&wr->chans[channo], ZT_EVENT_POLARITY);
+		}
+	} else if(wr->mod[channo].fxo.readcid && wr->intcount > wr->mod[channo].fxo.cidtimer + 2000) {
+        /* reset flags if it's been a while */
+		wr->mod[channo].fxo.cidtimer = wr->intcount;
+		wr->mod[channo].fxo.readcid = 0;
+	}
+}
+#endif
+
 /******************************************************************************
 ** wp_tdmv_rx_chan() - 
 **
@@ -1555,6 +1592,10 @@ DEBUG_EVENT("Module %d: RX: %02X %02X %02X %02X %02X %02X %02X %02X\n",
 	wr->chans[channo].readchunk = rxbuf;	
 	wr->chans[channo].writechunk = txbuf;	
 
+#ifdef WAN_FAKE_POLARITY
+	wp_tdmv_dtmfcheck_fakepolarity(wr,channo,rxbuf);
+#endif
+
 
 #ifdef CONFIG_PRODUCT_WANPIPE_TDM_VOICE_ECHOMASTER
 	wp_tdmv_echo_check(wan_tdmv, &wr->chans[channo], channo);
