@@ -243,7 +243,7 @@ static int sdla_ds3_rx_isr(sdla_fe_t *fe)
 	/* RxDS3 Interrupt status register (0x13) */
 	value = READ_REG(REG_RxDS3_INT_STATUS);
 	status = READ_REG(REG_RxDS3_CFG_STATUS);
-	if (fe->fe_cfg.frame == WAN_FR_DS3_Cbit && value & BIT_RxDS3_INT_STATUS_CPBIT_ERR){
+	if (WAN_FE_FRAME(fe) == WAN_FR_DS3_Cbit && value & BIT_RxDS3_INT_STATUS_CPBIT_ERR){
 		DEBUG_TE3("%s: CP Bit Error interrupt detected!\n",
 						fe->name);
 	}
@@ -291,7 +291,7 @@ static int sdla_ds3_rx_isr(sdla_fe_t *fe)
 			fe->fe_alarm &= ~WAN_TE3_BIT_YEL_ALARM;
 		}
 	}
-	if (fe->fe_cfg.frame == WAN_FR_DS3_Cbit && value & BIT_RxDS3_INT_STATUS_AIC){
+	if (WAN_FE_FRAME(fe) == WAN_FR_DS3_Cbit && value & BIT_RxDS3_INT_STATUS_AIC){
 		DEBUG_TE3("%s: AIC bit-field status %s!\n",
 				fe->name,
 				(status & BIT_RxDS3_STATUS_RxAIC) ? "ON" : "OFF");
@@ -782,10 +782,11 @@ sdla_te3_set_lb_modes(sdla_fe_t *fe, unsigned char type, unsigned char mode)
  */
 static int sdla_te3_udp(sdla_fe_t *fe, void *pudp_cmd, unsigned char *data)
 {
-	sdla_t		*card = (sdla_t*)fe->card;
-	wan_cmd_t	*udp_cmd = (wan_cmd_t*)pudp_cmd;
-	wan_femedia_t	*fe_media;
-	int		err = -EINVAL;
+	sdla_t			*card = (sdla_t*)fe->card;
+	wan_femedia_t		*fe_media = NULL;
+	sdla_fe_debug_t	*fe_debug = NULL;
+	wan_cmd_t		*udp_cmd = (wan_cmd_t*)pudp_cmd;
+	int			err = -EINVAL;
 
 	switch(udp_cmd->wan_cmd_command){
 	case WAN_GET_MEDIA_TYPE:
@@ -838,6 +839,26 @@ static int sdla_te3_udp(sdla_fe_t *fe, void *pudp_cmd, unsigned char *data)
     	    	udp_cmd->wan_cmd_data_len = sizeof(sdla_te_cfg_t);
 	    	break;
 
+	case WAN_FE_SET_DEBUG_MODE:
+		fe_debug = (sdla_fe_debug_t*)&data[0];
+		switch(fe_debug->type){
+		case WAN_FE_DEBUG_REG:
+			if (fe_debug->fe_debug_reg.read){
+				fe_debug->fe_debug_reg.value = 
+						READ_REG(fe_debug->fe_debug_reg.reg);
+			}else{
+				WRITE_REG(fe_debug->fe_debug_reg.reg, fe_debug->fe_debug_reg.value);
+			}
+			udp_cmd->wan_cmd_return_code = WAN_CMD_OK;
+			break;
+		
+		default:
+			udp_cmd->wan_cmd_return_code = WAN_UDP_INVALID_CMD;
+			break;
+		}
+    	    	udp_cmd->wan_cmd_data_len = 0;
+		break;
+
 	default:
 		udp_cmd->wan_cmd_return_code = WAN_UDP_INVALID_CMD;
 	    	udp_cmd->wan_cmd_data_len = 0;
@@ -1077,7 +1098,7 @@ static int sdla_te3_config(void *p_fe)
 		return -EINVAL;
 	}
 
-	switch(fe_cfg->frame){
+	switch(WAN_FE_FRAME(fe)){
 	case WAN_FR_E3_G751:
 		if (fe_cfg->media != WAN_MEDIA_E3){
 			DEBUG_EVENT("%s: (T3/E3) Invalid Frame Format!\n",
@@ -1128,7 +1149,7 @@ static int sdla_te3_config(void *p_fe)
 	WRITE_REG(REG_OPMODE, data);
 
 	data = 0x00;
-	switch(fe_cfg->lcode){
+	switch(WAN_FE_LCODE(fe)){
 	case WAN_LCODE_AMI: 
 		DEBUG_TE3("%s: (T3/E3) Line code AMI\n",
 				fe->name);
@@ -1216,7 +1237,7 @@ static int sdla_te3_update_pmon_info(sdla_fe_t* fe, struct seq_file* m, int* sto
 		"Line Code Violation", fe->fe_stats.u.te3_pmon.pmon_lcv,
 		"Framing Bit/Byte Error", fe->fe_stats.u.te3_pmon.pmon_framing);
 	if (IS_DS3(&fe->fe_cfg)){
-		if (fe->fe_cfg.frame == WAN_FR_DS3_Cbit){
+		if (WAN_FE_FRAME(fe) == WAN_FR_DS3_Cbit){
 			PROC_ADD_LINE(m,
 				PROC_STATS_PMON_FORMAT,
 				"Parity Error", fe->fe_stats.u.te3_pmon.pmon_parity,
