@@ -255,6 +255,7 @@ sub gen_wanpipe_conf{
 	my $dchan = 0;
 	my $fe_lbo;
        	my $fe_cpu;
+	my $tdm_voice_op_mode = "TDM_VOICE";
 
 	my $device_alpha = &get_alpha_from_num($device_no);
 
@@ -294,6 +295,15 @@ sub gen_wanpipe_conf{
 		$fe_lbo='120OH';
 		$te_sig_mode_line= 'TE_SIG_MODE     = '.$te_sig_mode;
 	}
+
+	if($self->signalling eq 'TDM API'){
+        	$tdm_voice_op_mode = "TDM_VOICE_API";
+		#for tdm_api hw_dchan is set by user
+		$dchan = $self->hw_dchan;
+		
+	}
+
+
 	open(FH, $wanpipe_conf_template ) or die "Cannot open $wanpipe_conf_template";
 	my $wp_file='';
        	while (<FH>) {
@@ -309,7 +319,7 @@ sub gen_wanpipe_conf{
 	} else {
 		$wp_file =~ s/IFNUM/$device_no/g;
 	}
-
+	$wp_file =~ s/TDM_VOICE_OP_MODE/$tdm_voice_op_mode/g;
         $wp_file =~ s/SLOTNUM/$pci_slot/g;
         $wp_file =~ s/BUSNUM/$pci_bus/g;
         $wp_file =~ s/FEMEDIA/$fe_media/g;
