@@ -9,6 +9,10 @@
 #               as published by the Free Software Foundation; either version
 #               2 of the License, or (at your option) any later version.
 # ----------------------------------------------------------------------------
+# Aug 6	   2008	 2.18   Jignesh Patel	Added Support for USB 100 (U10x.pm,wanpipe.tdm.u100)
+# Aug 1	   2008  2.17 	Jignesh Patel 	Support for Analog & a101/2 card for wancfg_tdmapi
+# 					Update A10u.pm,A20x.pm,wanpipe.tdm.a10u/a200
+# Jul 22   2008  2.17	Jignesh Patel	Support for FreeBSD ztcfg path 
 # Jun 6	   2008  2.16	Jignesh Patel	Added Zaptel Timer option for a500 cards
 # May 28   2008  2.15   Jignesh Patel   Minor d-chan update for FreeBSD- A10x.pm update
 # May 27   2008  2.14   Jignesh Patel   Added XMPT2 only option for SS7 
@@ -37,7 +41,7 @@
 system('clear');
 print "\n########################################################################";
 print "\n#    Sangoma Wanpipe:  Zaptel/SMG/TDMAPI/BOOT Configuration Script     #";
-print "\n#                             v2.16                                    #";
+print "\n#                             v2.18                                    #";
 print "\n#                     Sangoma Technologies Inc.                        #";
 print "\n#                        Copyright(c) 2008.                            #";
 print "\n########################################################################\n\n";
@@ -50,6 +54,7 @@ use A10x;
 use A10u;
 use A20x;
 use A50x;
+use U10x;
 
 
 my $FALSE = 1;
@@ -72,7 +77,7 @@ if ($os_type_list =~ m/Linux/){
 	$rc_dir=$etc_dir;
 	$module_load="modprobe";
 	$module_unload="modprobe -r";
-	$module_list="modprobe -l";
+	$module_list="lsmod";
 	$include_dir="/usr/include";
 }elsif ($os_type_list =~ m/FreeBSD/){
 	$os_type_name="FreeBSD";
@@ -105,6 +110,9 @@ my $current_tdmapi_span=1;
 my $current_zap_channel=1;
 my $num_analog_devices=0;
 my $num_analog_devices_total=0;
+my $num_usb_devices=0;
+my $num_usb_devices_total=0;
+my $num_usb_devices=0;
 my $num_bri_devices=0;
 my $num_bri_devices_total=0;
 my $num_digital_devices=0;
@@ -116,7 +124,7 @@ my $max_chans=0;
 my $ss7_tdmvoicechans='';
 my $ss7_array_length=0;
 
-
+my $ztcfg_path='';
 
 my $device_has_hwec=$FALSE;
 my $device_has_normal_clock=$FALSE;
@@ -207,6 +215,8 @@ my $tdm_api_span_num=0;
 my $zaptel_installed=$FALSE;
 my $modprobe_list=`$module_list`;
 my $is_ss7_xmpt2_only = $FALSE;
+#older release doesn't support USB
+my $usb_device_support = $FALSE;
 
 
 read_args();
@@ -256,13 +266,22 @@ my $woomera_conf_file_t="$asterisk_conf_dir/woomera.conf";
 my $date=`date +%F`;
 chomp($date);
 my $debug_tarball="$wanpipe_conf_dir/debug-".$date.".tgz";
-if( $zaptel_installed==$TRUE && $os_type_list =~ m/Linux/ ){
+	
+if ($os_type_list =~ m/FreeBSD/ && $zaptel_installed==$TRUE) {
+	parse_wanrouter_rc();
+	update_zaptel_cfg_script();
+}
+
+if( $zaptel_installed==$TRUE && $os_type_list =~ m/Linux/ ) {
 	set_zaptel_hwhdlc();
 }
 prepare_files();
 config_t1e1();
 config_bri();
 config_analog();
+if($usb_device_support == $TRUE && $os_type_list =~ m/Linux/) {
+	config_usbfxo();
+}
 config_tdmv_dummy();
 summary();
 apply_changes();
@@ -538,6 +557,7 @@ sub config_boot_linux{
 
 
 sub config_ztcfg_start{
+	
 	if ($num_zaptel_config ==0 || $silent==$TRUE){
 		return;
 	}
@@ -549,7 +569,9 @@ sub config_ztcfg_start{
 			if ( ! -d "$wanpipe_conf_dir/scripts" ) {
 				exec_command("mkdir -p $wanpipe_conf_dir/scripts");
 			} 
-			exec_command("cp -f $current_dir/templates/zaptel_cfg_script $wanpipe_conf_dir/scripts/start");	
+						
+			exec_command("cp -f $current_dir/templates/zaptel_cfg_script $wanpipe_conf_dir/scripts/start");
+			
 		}
 	}
 }
@@ -598,7 +620,7 @@ sub config_smg_ctrl_start{
 }
 	
 sub check_zaptel{
-	if ((system("lsmod | grep zaptel > /dev/null 2>  /dev/null")) == 0) {
+	if ((system("$module_list | grep zaptel > /dev/null 2>  /dev/null")) == 0){
 		$zaptel_installed=$TRUE;
 	}
 }
@@ -741,8 +763,7 @@ sub apply_changes{
 		if ($num_zaptel_config != 0){	
 			print "Loading Zaptel...\n";	
 			sleep 2;
-			exec_command("ztcfg -v");   
-#			}	 
+			exec_command("$ztcfg_path\ztcfg  -v");	 
 		}
 		if ($is_trixbox==$TRUE){
 			print "\nStarting Amportal...\n";
@@ -956,6 +977,41 @@ sub prepare_files{
 	if ( -f $zapata_conf_file_t ) {
 		exec_command("cp -f $zapata_conf_file_t $zapata_conf_file_t.bak");
 	}
+
+}
+sub parse_wanrouter_rc
+{	
+	#Set ztcfg_path based on $etc_dir/wanpipe/wanrouter.rc
+	if ( -f "$etc_dir/wanpipe/wanrouter.rc" ) {
+		my $line= `cat $etc_dir/wanpipe/wanrouter.rc   | grep ZAPTEL_BIN_DIR`;
+		chop($line);
+			{
+			my @parts = split(/=/,$line);
+			$ztcfg_path="$parts[1]\/";
+			}
+		#Use this wanrouter.rc as new template 
+		my $command="cp -f $etc_dir/wanpipe/wanrouter.rc  $current_dir/templates/wanrouter.rc.template.new > /dev/null 2>/dev/null ";
+		$wanrouter_rc_template="$current_dir/templates/wanrouter.rc.template.new";
+
+	}
+
+}
+
+sub update_zaptel_cfg_script(){
+
+	#update zaptel_cfg_script based on ztcfg_path
+
+	my $sscript ="";
+	open (FH,"$current_dir/templates/zaptel_cfg_script");
+	
+	while (<FH>) {
+		$sscript .= $_;
+	}
+	close (FH);
+	open (FH,">$current_dir/templates/zaptel_cfg_script");
+	$sscript =~ s/.*ztcfg.*/$ztcfg_path\ztcfg -v/;
+	print FH $sscript;
+	close (FH);
 }
 
 sub clean_files{
@@ -1037,7 +1093,8 @@ sub summary{
 		print("  $num_digital_devices_total T1/E1 port(s) detected, $num_digital_devices configured\n");
 		print("  $num_bri_devices_total ISDN BRI port(s) detected, $num_bri_devices configured\n");
 		print("  $num_analog_devices_total analog card(s) detected, $num_analog_devices configured\n");
-		
+		print("  $num_usb_devices_total usb device(s) detected, $num_usb_devices configured\n");
+
 		print "\nConfigurator will create the following files:\n";
 		print "\t1. Wanpipe config files in $wanpipe_conf_dir\n";
 		$file_list++;
@@ -2126,21 +2183,7 @@ sub config_t1e1{
 #							$def_te_sig_mode = &prompt_user_list(@options, $def_te_sig_mode);
 								
 						}
-						if ($def_signalling eq 'TDM API'){	
-							printf("Select signalling mode on AFT-A%s port %s\n",$card->card_model, $port);
-							my @options=("CCS","CAS");
-							$def_te_sig_mode=&prompt_user_list(@options, $def_te_sig_mode);
-						} elsif ($def_signalling eq 'PRI CPE' | 
-						         $def_signalling eq 'PRI NET' | 
-							 $def_signalling eq 'SS7 - Sangoma Signal Media Gateway'|
-							 $def_signalling eq 'No Signaling (Voice Only)'){
-
-							$def_te_sig_mode="CCS";
-						} else {
-							$def_te_sig_mode="CAS";
-						}
-
-
+					
 					} else {
 						if($#silent_felcodes >= 0){
 							$silent_felcode=pop(@silent_felcodes);
@@ -2232,11 +2275,15 @@ sub config_t1e1{
 					if($#silent_signallings >= 0){
 						$silent_signalling=pop(@silent_signallings);
 					}
-					$def_signalling=$silent_signalling;
+					if($is_tdm_api == $TRUE){
+						$def_signalling="TDM API";
+					} else {
+						$def_signalling=$silent_signalling;
+					}
 				}
 				$a10x->signalling($def_signalling);
 				
-				if ($def_signalling eq 'TDM API'){	
+				if ($def_signalling eq 'TDM API' & $silent==$FALSE ){	
 					printf("Select signalling mode for port %s on %s\n", $port, $card->card_model);
 					my @options=("CCS","CAS");
 					$def_te_sig_mode=&prompt_user_list(@options, $def_te_sig_mode);
@@ -2503,10 +2550,9 @@ ENDSS7CONFIG:
 
 
 sub config_analog{
-	if($is_tdm_api==$TRUE){
-		return;
-	}
+
 	my $a20x;
+
 	if (!$first_cfg && $silent==$FALSE) {
 		system('clear');
 	}
@@ -2516,9 +2562,12 @@ sub config_analog{
 	print "------------------------------------\n";
 
 	my $skip_card=$FALSE;
-	$zaptel_conf.="\n";
-	$zapata_conf.="\n";
+	if($is_tdm_api == $FALSE) {
+		$zaptel_conf.="\n";
+		$zapata_conf.="\n";
+	}
 	foreach my $dev (@hwprobe) {
+		
 		if ( $dev =~ /(\d+).(\w+\w+).*SLOT=(\d+).*BUS=(\d+).*CPU=(\w+).*PORT=(\w+).*HWEC=(\d+)/){
 			$skip_card=$FALSE;
 			my $card = eval {new Card(); } or die ($@);
@@ -2557,7 +2606,7 @@ sub config_analog{
 					$a20x = eval {new A20x(); } or die ($@);
 					$a20x->card($card);
 					$card->first_chan($current_zap_channel);
-
+			
 					if ( $device_has_hwec==$TRUE && $silent==$FALSE){
 						print "Will this AFT-A$1 synchronize with an existing Sangoma T1/E1 card?\n";
 						print "\n WARNING: for hardware and firmware requirements, check:\n";
@@ -2569,7 +2618,7 @@ sub config_analog{
 							$a20x->rm_network_sync('YES');
 						}
 					} 
-
+				
 					if ($silent==$FALSE){
 						if ($card->hwec_mode eq "YES"){
 							$card->hw_dtmf(&prompt_hw_dtmf());
@@ -2597,38 +2646,42 @@ sub config_analog{
 						$a20x->tdm_law($silent_tdm_law);
 						
 					} 
-
-					
-					print "A$1 configured on slot:$3 bus:$4 span:$current_zap_span\n";
-					$zaptel_conf.="#Sangoma A$1 [slot:$3 bus:$4 span:$current_zap_span] <wanpipe".$a20x->card->device_no.">\n";
-					$zapata_conf.=";Sangoma A$1 [slot:$3 bus:$4 span:$current_zap_span]  <wanpipe".$a20x->card->device_no.">\n";
+			
 					$startup_string.="wanpipe$devnum ";
 					$cfg_string.="wanpipe$devnum ";
 					
 					if($silent==$FALSE){
 						prompt_user("Press any key to continue");
 					}
-			
-					$current_zap_channel+=24;
 					my $i;
-					$devnum++;
-					$num_analog_devices++;
-					$num_zaptel_config++;
-					$card->tdmv_span_no($current_zap_span);
-					$current_zap_span++;
-#					$a20x->gen_wanpipe_conf();
+					if( $is_tdm_api == $FALSE) {
+						print "A$1 configured on slot:$3 bus:$4 span:$current_zap_span\n";
+						$zaptel_conf.="#Sangoma A$1 [slot:$3 bus:$4 span:$current_zap_span] <wanpipe".$a20x->card->device_no.">\n";
+						$zapata_conf.=";Sangoma A$1 [slot:$3 bus:$4 span:$current_zap_span]  <wanpipe".$a20x->card->device_no.">\n";
+						$current_zap_channel+=24;	
+						$num_zaptel_config++;
+						$card->tdmv_span_no($current_zap_span);
+						$current_zap_span++;
+					}else{
+						print "A$1 configured on slot:$3 bus:$4 span:$current_tdmapi_span\n";
+						$a20x->is_tdm_api($TRUE);
+						$card->tdmv_span_no($current_tdmapi_span);
+						$current_tdmapi_span++;
+					}
+						$devnum++;
+						$num_analog_devices++;
 					if ($os_type_list =~ m/FreeBSD/){
 						$a20x->gen_wanpipe_conf(1);
 					} else {
 						$a20x->gen_wanpipe_conf(0);
 					}
-
+					
 				}else{
 					print "A$1 on slot:$3 bus:$4 not configured\n";
 					prompt_user("Press any key to continue");
 				}
 			}
-		}elsif ( $dev =~ /(\d+):FXS/ & $skip_card==$FALSE){
+		}elsif ( $dev =~ /(\d+):FXS/ & $skip_card==$FALSE & $is_tdm_api==$FALSE){
 			my $zap_pos = $1+$current_zap_channel-25;
 			if($silent==$TRUE & $silent_zapata_context_opt == $TRUE){
 				if($#silent_zapata_contexts >= 0){
@@ -2641,7 +2694,7 @@ sub config_analog{
 			$a20x->card->zap_group("1");
 			$zaptel_conf.=$a20x->gen_zaptel_conf($zap_pos,"fxo");
 			$zapata_conf.=$a20x->gen_zapata_conf($zap_pos,"fxo");
-		}elsif ( $dev =~ /(\d+):FXO/ & $skip_card==$FALSE){
+		}elsif ( $dev =~ /(\d+):FXO/ & $skip_card==$FALSE & $is_tdm_api==$FALSE ){
 			my $zap_pos = $1+$current_zap_channel-25;
 			if($silent==$TRUE & $silent_zapata_context_opt == $TRUE){
 				if($#silent_zapata_contexts >= 0){
@@ -2667,7 +2720,7 @@ sub config_analog{
 sub config_tdmv_dummy 
 {
 	my $command='';
-	if( $num_digital_devices == 0 && $num_analog_devices == 0 && $num_bri_devices !=0 && $zaptel_installed==$TRUE && $os_type_list =~ m/Linux/  && $silent == $FALSE ){
+	if( $num_digital_devices == 0 && $num_analog_devices == 0 && $num_usb_devices == 0 && $num_bri_devices !=0 && $zaptel_installed==$TRUE && $os_type_list =~ m/Linux/  && $silent == $FALSE ){
 		system('clear');
 		print("Would you like to configure A500 BRI card as timing source for Zaptel?\n");
 		print("(Visit http://wiki.sangoma.com/wanpipe-linux-asterisk-appendix#bri-tdmv for more information)\n");		
@@ -2691,4 +2744,136 @@ sub config_tdmv_dummy
 
 	
 	
+}
+sub config_usbfxo{
+
+	my $u10x;
+	if (!$first_cfg && $silent==$FALSE) {
+		system('clear');
+	}
+	$first_cfg=0;
+	print "------------------------------------\n";
+	print "Configuring USB devices [U100]\n";
+	print "------------------------------------\n";
+
+	my $skip_card=$FALSE;
+	if($is_tdm_api == $FALSE) {
+		$zaptel_conf.="\n";
+		$zapata_conf.="\n";
+	}
+	foreach my $dev (@hwprobe) {
+			if ( $dev =~ / *.(\D\d+).*BUS=(\d+) /){
+		
+			$skip_card=$FALSE;
+			my $card = eval {new Card(); } or die ($@);
+			$card->current_dir($current_dir);
+			$card->cfg_dir($cfg_dir);
+			$card->device_no($devnum);
+			$card->card_model($1);
+			$card->pci_bus($2);
+			
+			if ($card->card_model eq 'U100'){
+				$num_usb_devices_total++;
+				if ($num_usb_devices_total >= 2){
+					if($silent==$FALSE) {
+						system('clear');
+						print("Only one USB U100 device is supported!!!\n");
+						prompt_user("Press any key to continue");
+					}
+
+				   return ;
+				}
+				if($silent==$FALSE) {
+					system('clear');
+					print "\n-----------------------------------------------------------\n";
+					print "USB $1 detected on  bus:$2\n";
+					print "-----------------------------------------------------------\n";
+				}
+				if($is_trixbox==$FALSE){
+					if ($silent==$FALSE){
+						print "\nWould you like to configure USB $1 on bus:$2\n";
+						if (&prompt_user_list(("YES","NO","")) eq 'NO'){
+							$skip_card=$TRUE;	
+						}
+					}
+				}
+				if ($skip_card==$FALSE){
+					
+					$u10x = eval {new U10x(); } or die ($@);
+					$u10x->card($card);
+					$card->first_chan($current_zap_channel);
+			
+									
+					if ($silent==$FALSE){
+						$u10x->tdm_law(&prompt_tdm_law());
+						$u10x->tdm_opermode(&prompt_tdm_opemode());
+		
+					} else {
+												
+						if($#silent_tdm_laws >= 0){
+							$silent_tdm_law=pop(@silent_tdm_laws);
+						}						
+						
+						$u10x->tdm_law($silent_tdm_law);
+						
+					} 
+			
+					$startup_string.="wanpipe$devnum ";
+					$cfg_string.="wanpipe$devnum ";
+					
+					if($silent==$FALSE){
+						prompt_user("Press any key to continue");
+					}
+					my $i;
+					if( $is_tdm_api == $FALSE) {
+						print "$1 configured on  bus:$2 span:$current_zap_span\n";
+						$zaptel_conf.="#Sangoma USB $1  [bus:$2 span:$current_zap_span] <wanpipe".$u10x->card->device_no.">\n";
+						$zapata_conf.=";Sangoma A$1 [slot:$3 bus:$4 span:$current_zap_span]  <wanpipe".$u10x->card->device_no.">\n";
+						$current_zap_channel+=2;	
+						$num_zaptel_config++;
+						$card->tdmv_span_no($current_zap_span);
+						$current_zap_span++;
+					}else{
+						print "A$1 configured on slot:$3 bus:$4 span:$current_tdmapi_span\n";
+						$u10x->is_tdm_api($TRUE);
+						$card->tdmv_span_no($current_tdmapi_span);
+						$current_tdmapi_span++;
+					}
+						$devnum++;
+						$num_usb_devices++;
+					if ($os_type_list =~ m/FreeBSD/){
+						$u10x->gen_wanpipe_conf(1);
+					} else {
+						$u10x->gen_wanpipe_conf(0);
+					}
+					for (my $mod = 0; $mod <= 1; $mod++){
+						my $zap_pos = $mod+$current_zap_channel-2;
+						if($silent==$TRUE & $silent_zapata_context_opt == $TRUE){
+							if($#silent_zapata_contexts >= 0){
+								$silent_zapata_context=pop(@silent_zapata_contexts);
+							}
+							$u10x->card->zap_context($silent_zapata_context);
+						} else {
+							$u10x->card->zap_context("from-zaptel");
+						}
+						$u10x->card->zap_group("0");
+						$zaptel_conf.=$u10x->gen_zaptel_conf($zap_pos,"fxs");
+						$zapata_conf.=$u10x->gen_zapata_conf($zap_pos,"fxs");
+					}
+					
+				}else{
+					print "$1 on  bus:$2 not configured\n";
+					prompt_user("Press any key to continue");
+				}
+			}
+		
+		}
+	}
+	if($num_usb_devices_total!=0){
+		print("\nUSB analog card configuration complete\n\n");
+		if( $silent==$FALSE){
+			prompt_user("Press any key to continue");
+		}
+	}
+
 }
