@@ -82,6 +82,7 @@
 extern wan_femedia_t	femedia;
 extern char *csudsu_menu_te1_pmc[];
 extern char *csudsu_menu_te1_dm[];
+extern char *csudsu_menu_te3[];
 
 /******************************************************************************
  * 			FUNCTION PROTOTYPES				      *
@@ -181,6 +182,8 @@ char ** AFTget_cmd_menu(char *cmd_name,int *len)
 			}else{
 				cmd_menu = csudsu_menu;
 			}
+		}else if (femedia.media == WAN_MEDIA_DS3 || femedia.media == WAN_MEDIA_E3){  
+			cmd_menu = csudsu_menu_te3;
 		}else{
 			cmd_menu = csudsu_menu;
 		}
@@ -1150,12 +1153,12 @@ int AFTUsage(void)
 	printf("\t   T         a       Read T1/E1/56K alarms.\n"); 
 	printf("\t             lt      Diagnostic Digital Loopback testing (T1/E1 card only)\n"); 
 	printf("\t             lb      Read Loopback status (T1/E1 cards)\n");  
-	printf("\t             allb    Active Line/Remote Loopback mode (T1/E1/T3/E3 cards)\n");  
-	printf("\t             dllb    Deactive Line/Remote Loopback mode (T1/E1/T3/E3 cards)\n");  
-	printf("\t             aplb    Active Payload Loopback mode (T1/E1/T3/E3 cards)\n");  
-	printf("\t             dplb    Deactive Payload Loopback mode (T1/E1/T3/E3 cards)\n");  
-	printf("\t             adlb    Active Diagnostic Digital Loopback mode (T1/E1/T3/E3 cards)\n");  
-	printf("\t             ddlb    Deactive Diagnostic Digital Loopback mode (T1/E1/T3/E3 cards)\n");  
+	printf("\t             allb    Active Line/Remote Loopback mode (T1/E1 cards)\n");  
+	printf("\t             dllb    Deactive Line/Remote Loopback mode (T1/E1 cards)\n");  
+	printf("\t             aplb    Active Payload Loopback mode (T1/E1 cards)\n");  
+	printf("\t             dplb    Deactive Payload Loopback mode (T1/E1 cards)\n");  
+	printf("\t             adlb    Active Diagnostic Digital Loopback mode (T1/E1 cards)\n");  
+	printf("\t             ddlb    Deactive Diagnostic Digital Loopback mode (T1/E1 cards)\n");  
 	printf("\t             salb    Send Loopback Activate Code (T1/E1 PMC card only)\n");  
 	printf("\t             sdlb    Send Loopback Deactive Code (T1/E1 PMC card only)\n");  
 	printf("\t             alalb   Active LIU Analog Loopback mode (T1/E1 DM card only)\n");  
@@ -1166,6 +1169,12 @@ int AFTUsage(void)
 	printf("\t             dlrlb   Deactive LIU Remote Loopback mode (T1/E1 DM card only)\n");  
 	printf("\t             aldlb   Active LIU Dual Loopback mode (T1/E1 DM card only)\n");  
 	printf("\t             dldlb   Deactive LIU Dual Loopback mode (T1/E1 DM card only)\n");
+	printf("\t             allb3   Active Analog Local Loopback mode (DS3/E3 cards)\n");  
+	printf("\t             dllb3   Deactive Analog Local Loopback mode (DS3/E3 cards)\n");  
+	printf("\t             arlb3   Active Remote Loopback mode (DS3/E3 cards)\n");  
+	printf("\t             drlb3   Deactive Remote Loopback mode (DS3/E3 cards)\n");  
+	printf("\t             adlb3   Active Digital Loopback mode (DS3/E3 cards)\n");  
+	printf("\t             ddlb3   Deactive Digital Loopback mode (DS3/E3 cards)\n");  
 	printf("\t             txe     Enable TX (AFT card only)\n");  
 	printf("\t             txd     Disable TX (AFT card only)\n");  
 	printf("\tFlush Statistics\n");
@@ -1369,6 +1378,19 @@ int AFTMain(char *command,int argc, char* argv[])
 				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_LB_ENABLE);
 			}else if (!strcmp(opt,"dfplb")){
 				set_lb_modes(WAN_TE1_FR_PLB_MODE, WAN_TE1_LB_DISABLE);
+
+			}else if (!strcmp(opt,"allb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_ANALOG, WAN_TE1_LB_ENABLE);
+			}else if (!strcmp(opt,"dllb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_ANALOG, WAN_TE1_LB_DISABLE);
+			}else if (!strcmp(opt,"arlb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_REMOTE, WAN_TE1_LB_ENABLE);
+			}else if (!strcmp(opt,"drlb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_REMOTE, WAN_TE1_LB_DISABLE);
+			}else if (!strcmp(opt,"adlb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_DIGITAL, WAN_TE1_LB_ENABLE);
+			}else if (!strcmp(opt,"ddlb3")){
+				set_lb_modes(WAN_TE3_LIU_LB_DIGITAL, WAN_TE1_LB_DISABLE);
 			}else if (!strcmp(opt,"a")){
 				read_te1_56k_stat(0);
 			}else if (!strcmp(opt,"af")){
