@@ -118,16 +118,29 @@ char *csudsu_menu[]={
 "."
 };
 
+char *csudsu_menu_te3[]={
+"","-- DS3/E3 (AFT) Stats --",
+""," ",
+"Ta","Read DS3/E3 alarms",
+"Tallb3","E Analog Local Loopback DS3/E3",
+"Tdllb3","D Analog Local Loopback DS3/E3",
+"Tarlb3","E Remote Loopback DS3/E3",
+"Tdrlb3","D Remote Loopback DS3/E3",
+"Tadlb3","E Digital Loopback DS3/E3",
+"Tddlb3","D Digital Loopback DS3/E3",
+"."
+};
+
 char *csudsu_menu_te1_pmc[]={
 "","-- T1/E1 (S514-4-5-7-8/AFT) Stats --",
 ""," ",
 "Ta","Read T1/E1 alarms",
-"Tallb","E Line/Remote Loopback T1/E1/DS3/E3",
-"Tdllb","D Line/Remote Loopback T1/E1/DS3/E3",
-"Taplb","E Payload Loopback T1/E1/DS3/E3",
-"Tdplb","D Payload Loopback T1/E1/DS3/E3",
-"Tadlb","E Diag Digital Loopback T1/E1/DS3/E3",
-"Tddlb","D Diag Digital Loopback T1/E1/DS3/E3",
+"Tallb","E Line/Remote Loopback T1/E1",
+"Tdllb","D Line/Remote Loopback T1/E1",
+"Taplb","E Payload Loopback T1/E1",
+"Tdplb","D Payload Loopback T1/E1",
+"Tadlb","E Diag Digital Loopback T1/E1",
+"Tddlb","D Diag Digital Loopback T1/E1",
 "Tsalb","Send Loopback Activate Code",  
 "Tsdlb","Send Loopback Deactive Code",  
 "Tread","Read CSU/DSU cfg",
